@@ -22,8 +22,9 @@ do_cmd "0" --dry-run allow 25/tcp
 do_cmd "0" --dry-run allow smtp
 do_cmd "0" --dry-run deny proto tcp to any port 80
 do_cmd "0" --dry-run deny proto tcp from 10.0.0.0/8 to 192.168.0.1 port 25
-do_cmd "0" --dry-run allow 80/tcp
-do_cmd "0" --dry-run delete allow 80/tcp
+do_cmd "0" --dry-run deny 80/tcp
+do_cmd "0" --dry-run delete deny 80/tcp
+do_cmd "0" --dry-run limit ssh/tcp
 do_cmd "0" --dry-run deny 53
 do_cmd "0" --dry-run allow 80/tcp
 do_cmd "0" --dry-run allow from 10.0.0.0/8
@@ -33,6 +34,8 @@ do_cmd "0" --dry-run deny proto udp from 1.2.3.4 to any port 514
 do_cmd "0" --dry-run allow proto udp from 1.2.3.5 port 5469 to 1.2.3.4 port 5469
 
 echo "SIMPLE" >> $TESTTMP/result
+do_cmd "0" --dry-run allow 1
+do_cmd "0" --dry-run allow 9/udp
 do_cmd "0" --dry-run allow 25
 do_cmd "0" --dry-run allow 25/tcp
 do_cmd "0" --dry-run allow 25/udp
@@ -57,7 +60,7 @@ do_cmd "0" --dry-run delete allow ssh/udp
 echo "TO/FROM" >> $TESTTMP/result
 from="192.168.0.1"
 to="10.0.0.1"
-for x in allow deny
+for x in allow deny limit
 do
 	do_cmd "0" --dry-run $x from $from
 	do_cmd "0" --dry-run delete $x from $from
@@ -162,4 +165,46 @@ do_cmd "0" --dry-run allow from 192.168.0.0/16
 do_cmd "0" --dry-run allow from 192.168.0.1/32
 do_cmd "0" --dry-run allow from 192.168.0.1/32 to 192.168.0.2/32
 
+echo "ISP style" >> $TESTTMP/result
+do_cmd "0" --dry-run allow from 192.168.0.2/255.255.0.2
+
+echo "Multiports:" >> $TESTTMP/result
+for i in 192.168.0 any; do
+    for j in from to; do
+        k="to"
+        if [ "$j" = "to" ]; then
+            k="from"
+        fi
+        m="$i.1"
+        n="$i.2"
+        if [ "$i" = "any" ]; then
+            m="$i"
+            n="$i"
+        fi
+        do_cmd "0" --dry-run allow $j $m port 34,35 proto tcp
+        do_cmd "0" --dry-run allow $j $m port 34,35:39 proto udp
+        do_cmd "0" --dry-run allow $j $m port 35:39 proto tcp
+        do_cmd "0" --dry-run allow $j $m port 221,23,21,15:19,22 proto udp
+        do_cmd "0" --dry-run allow $j $m port 34,35 $k $n port 24 proto tcp
+        do_cmd "0" --dry-run allow $j $m port 34,35:39 $k $n port 24 proto udp
+        do_cmd "0" --dry-run allow $j $m port 35:39 $k $n port 24 proto tcp
+        do_cmd "0" --dry-run allow $j $m port 23,21,15:19,22 $k $n port 24 proto udp
+        do_cmd "0" --dry-run allow $j $m port 34,35 $k $n port 24:26 proto tcp
+        do_cmd "0" --dry-run allow $j $m port 34,35:39 $k $n port 24:26 proto udp
+        do_cmd "0" --dry-run allow $j $m port 35:39 $k $n port 24:26 proto tcp
+        do_cmd "0" --dry-run allow $j $m port 23,21,15:19,22 $k $n port 24:26 proto udp
+    done
+done
+
+# simple syntax
+for i in allow deny limit; do
+    for j in tcp udp; do
+	do_cmd "0" --dry-run $i 34,35/$j
+	do_cmd "0" --dry-run $i 34,35:39/$j
+	do_cmd "0" --dry-run $i 35:39/$j
+	do_cmd "0" --dry-run $i 23,21,15:19,22/$j
+	do_cmd "0" --dry-run $i 1,9/$j
+    done
+done
+
 exit 0
