@@ -23,7 +23,7 @@ do_cmd "0" --dry-run deny proto tcp from 2001:db8::/32 to any port 25
 echo "TO/FROM" >> $TESTTMP/result
 from="2001:db8::/32"
 to="2001:db8:3:4:5:6:7:8"
-for x in allow deny
+for x in allow deny limit
 do
 	do_cmd "0" --dry-run $x from $from
 	do_cmd "0" --dry-run delete $x from $from
@@ -73,4 +73,33 @@ do_cmd "0" --dry-run allow from ::1/32
 do_cmd "0" --dry-run allow from ::1/128
 do_cmd "0" --dry-run allow from ::1/32 to ::1/128
 
+
+echo "Multiports:" >> $TESTTMP/result
+for i in 2001:0db8:85a3:08d3:1319:8a2e:0370:734 any; do
+    for j in from to; do
+        k="to"
+        if [ "$j" = "to" ]; then
+            k="from"
+        fi
+        m="${i}1"
+        n="${i}2"
+        if [ "$i" = "any" ]; then
+            m="$i"
+            n="$i"
+        fi
+        do_cmd "0" --dry-run allow $j $m port 34,35 proto tcp
+        do_cmd "0" --dry-run allow $j $m port 34,35:39 proto udp
+        do_cmd "0" --dry-run allow $j $m port 35:39 proto tcp
+        do_cmd "0" --dry-run allow $j $m port 210,23,21,15:19,22 proto udp
+        do_cmd "0" --dry-run allow $j $m port 34,35 $k $n port 24 proto tcp
+        do_cmd "0" --dry-run allow $j $m port 34,35:39 $k $n port 24 proto udp
+        do_cmd "0" --dry-run allow $j $m port 35:39 $k $n port 24 proto tcp
+        do_cmd "0" --dry-run allow $j $m port 23,21,15:19,22 $k $n port 24 proto udp
+        do_cmd "0" --dry-run allow $j $m port 34,35 $k $n port 24:26 proto tcp
+        do_cmd "0" --dry-run allow $j $m port 34,35:39 $k $n port 24:26 proto udp
+        do_cmd "0" --dry-run allow $j $m port 35:39 $k $n port 24:26 proto tcp
+        do_cmd "0" --dry-run allow $j $m port 23,21,15:19,22 $k $n port 24:26 proto udp
+    done
+done
+
 exit 0
