@@ -60,10 +60,7 @@ do_cmd "0"  deny 25
 do_cmd "0"  deny 1 
 do_cmd "0"  deny 65535 
 grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
-do_cmd "0"  delete allow 25 
 do_cmd "0"  delete deny 25 
-do_cmd "0"  delete allow smtp 
-do_cmd "0"  delete deny smtp 
 do_cmd "0"  delete deny 1 
 do_cmd "0"  delete deny 65535 
 grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
@@ -79,6 +76,8 @@ do_cmd "0"  deny to any port 80 proto tcp
 grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
 do_cmd "0"  deny from 10.0.0.0/8 to 192.168.0.1 port 25 proto tcp
 grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0"  limit 22/tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
 do_cmd "0"  deny 53
 grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
 do_cmd "0"  allow 80/tcp
@@ -94,10 +93,9 @@ grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
 do_cmd "0"  allow from 1.2.3.5 port 5469 proto udp to 1.2.3.4 port 5469
 grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
 
-do_cmd "0"  delete allow 53
 do_cmd "0"  delete allow 25/tcp
-do_cmd "0"  delete deny to any port 80 proto tcp
 do_cmd "0"  delete deny from 10.0.0.0/8 to 192.168.0.1 port 25 proto tcp
+do_cmd "0"  delete limit 22/tcp
 do_cmd "0"  delete deny 53
 do_cmd "0"  delete allow 80/tcp
 do_cmd "0"  delete allow from 10.0.0.0/8
@@ -178,41 +176,45 @@ grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
 echo "TO/FROM" >> $TESTTMP/result
 from="192.168.0.1"
 to="10.0.0.1"
-for x in allow deny
+for x in allow deny limit
 do
+        context="2"
+        if [ "$x" = "limit" ]; then
+                context="5"
+        fi
         do_cmd "0"  $x from $from
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  delete $x from $from
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  $x to $to
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  delete $x to $to
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  $x to $to from $from
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  delete $x to $to from $from
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
 
         do_cmd "0"  $x from $from port 80
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  delete $x from $from port 80
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  $x to $to port 25
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  delete $x to $to port 25
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  $x to $to from $from port 80
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  delete $x to $to from $from port 80
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  $x to $to port 25 from $from
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  delete $x to $to port 25 from $from
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  $x to $to port 25 from $from port 80
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         do_cmd "0"  delete $x to $to port 25 from $from port 80
-	grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+	grep -A$context "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
         for y in udp tcp
         do
                 do_cmd "0"  $x from $from port 80 proto $y
@@ -388,5 +390,53 @@ do_cmd "0" allow from 192.168.0.1/32 to 192.168.0.2/32
 grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
 do_cmd "0" delete allow from 192.168.0.1/32 to 192.168.0.2/32
 grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" allow from 192.168.0.2/255.255.0.2 
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" delete allow from 192.168.0.2/255.255.0.2
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+
+echo "LP bug 237446" >> $TESTTMP/result
+do_cmd "0" allow to 111.12.34.2/4
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" delete allow to 111.12.34.2/4
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" allow from 111.12.34.2/4
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" delete allow from 96.0.0.0/4
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+
+echo "TESTING MULTIPORT" >> $TESTTMP/result
+do_cmd "0" allow to 192.168.0.1 port 80:83 proto tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" delete allow to 192.168.0.1 port 80:83 proto tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" allow to 192.168.0.1 port 80:83,22 proto tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" delete allow to 192.168.0.1 port 80:83,22 proto tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" allow from 192.168.0.1 port 35:39 to 192.168.0.2 port 22 proto tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" delete allow from 192.168.0.1 port 35:39 to 192.168.0.2 port 22 proto tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" allow to any port 23,21,15:19,22 from any port 24:26 proto udp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" delete allow to any port 23,21,15:19,22 from any port 24:26 proto udp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" allow 34,35/tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" delete allow 34,35/tcp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" allow 34,35:39/udp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" delete allow 34,35:39/udp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" deny 35:39/udp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" delete deny 35:39/udp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" deny 23,21,15:19,22/udp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
+do_cmd "0" delete deny 23,21,15:19,22/udp
+grep -A2 "tuple" $TESTPATH/var/lib/ufw/user.rules >> $TESTTMP/result
 
 exit 0
